Python wrapper and simple addons for the sioyek PDF viewer. Addons:

* `paper_downloader`: Download the paper name under cursor from google scholar or scihub and open the document
* `dual_panelify`: Create a dual panel version of the current PDF file
* `embed_annotations`: Embed the sioyek bookmarks and highlights into the current file
* `extract_highlights`: Create a new document with the highlights of the current document with pre-inserted portal into the corresponding location in the original document
* `translate`: Translate the text and display it in sioyek statusbar